summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2012-03-09 21:19:44 -0600
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2012-03-10 07:08:54 -0600
commitae1b45a04699235546b4d725aa4eceec138ffacd (patch)
tree3c4f5d81c3be178388e145214e20307a5b524220
parent187694b9ec393421fec8d1e39a16cf405b856fa9 (diff)
downloadlibpng-ae1b45a04699235546b4d725aa4eceec138ffacd.tar.gz
[master] Imported from libpng-1.5.10beta04.tar
-rw-r--r--ANNOUNCE23
-rw-r--r--CHANGES7
-rw-r--r--CMakeLists.txt2
-rw-r--r--LICENSE4
-rw-r--r--README2
-rwxr-xr-xconfigure22
-rw-r--r--configure.ac4
-rw-r--r--libpng-manual.txt12
-rw-r--r--libpng.322
-rw-r--r--libpngpf.34
-rw-r--r--png.52
-rw-r--r--png.c6
-rw-r--r--png.h18
-rw-r--r--pngconf.h6
-rw-r--r--pngtest.c2
-rw-r--r--pngwutil.c15
-rw-r--r--projects/vstudio/readme.txt2
-rw-r--r--projects/vstudio/zlib.props2
-rw-r--r--scripts/README.txt12
-rwxr-xr-xscripts/libpng-config-head.in2
-rw-r--r--scripts/libpng.pc.in2
-rw-r--r--scripts/makefile.ne12bsd2
-rw-r--r--scripts/makefile.netbsd2
-rw-r--r--scripts/makefile.openbsd2
-rw-r--r--scripts/pnglibconf.h.prebuilt2
-rw-r--r--scripts/symbols.def2
26 files changed, 95 insertions, 86 deletions
diff --git a/ANNOUNCE b/ANNOUNCE
index 1b08b26b5..99b0f42ff 100644
--- a/ANNOUNCE
+++ b/ANNOUNCE
@@ -1,5 +1,5 @@
-Libpng 1.5.10beta03 - March 5, 2012
+Libpng 1.5.10beta04 - March 10, 2012
This is not intended to be a public release. It will be replaced
within a few weeks by a public version or by another test version.
@@ -9,20 +9,20 @@ Files available for download:
Source files with LF line endings (for Unix/Linux) and with a
"configure" script
- 1.5.10beta03.tar.xz (LZMA-compressed, recommended)
- 1.5.10beta03.tar.gz
- 1.5.10beta03.tar.bz2
+ 1.5.10beta04.tar.xz (LZMA-compressed, recommended)
+ 1.5.10beta04.tar.gz
+ 1.5.10beta04.tar.bz2
Source files with CRLF line endings (for Windows), without the
"configure" script
- lp1510b03.7z (LZMA-compressed, recommended)
- lp1510b03.zip
+ lp1510b04.7z (LZMA-compressed, recommended)
+ lp1510b04.zip
Other information:
- 1.5.10beta03-README.txt
- 1.5.10beta03-LICENSE.txt
+ 1.5.10beta04-README.txt
+ 1.5.10beta04-LICENSE.txt
Changes since the last public release (1.5.9):
@@ -45,11 +45,16 @@ Version 1.5.10beta01 [February 24, 2012]
Version 1.5.10beta02 [February 27, 2012]
Updated Makefile.in
-Version 1.5.10beta03 [March 5, 2012]
+Version 1.5.10beta03 [March 6, 2012]
Removed unused "current_text" members of png_struct and the png_free()
of png_ptr->current_text from pngread.c
Added palette-index checking.
+Version 1.5.10beta04 [March 10, 2012]
+ Fixed PNG_LIBPNG_BUILD_BASE_TYPE definition.
+ Fixed CMF optimization of non-IDAT compressed chunks, which was added at
+ libpng-1.5.4. It sometimes produced too small of a window.
+
Send comments/corrections/commendations to png-mng-implement at lists.sf.net:
(subscription required; visit
https://lists.sourceforge.net/lists/listinfo/png-mng-implement
diff --git a/CHANGES b/CHANGES
index 280c46734..a270114f0 100644
--- a/CHANGES
+++ b/CHANGES
@@ -3830,11 +3830,16 @@ Version 1.5.10beta01 [February 24, 2012]
Version 1.5.10beta02 [February 27, 2012]
Updated Makefile.in
-Version 1.5.10beta03 [March 5, 2012]
+Version 1.5.10beta03 [March 6, 2012]
Removed unused "current_text" members of png_struct and the png_free()
of png_ptr->current_text from pngread.c
Added palette-index checking.
+Version 1.5.10beta04 [March 10, 2012]
+ Fixed PNG_LIBPNG_BUILD_BASE_TYPE definition.
+ Fixed CMF optimization of non-IDAT compressed chunks, which was added at
+ libpng-1.5.4. It sometimes produced too small of a window.
+
Send comments/corrections/commendations to png-mng-implement at lists.sf.net
(subscription required; visit
https://lists.sourceforge.net/lists/listinfo/png-mng-implement
diff --git a/CMakeLists.txt b/CMakeLists.txt
index dd1831980..1b0040f69 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -225,7 +225,7 @@ endif(NOT WIN32 OR CYGWIN OR MINGW)
# SET UP LINKS
if(PNG_SHARED)
set_target_properties(${PNG_LIB_NAME} PROPERTIES
-# VERSION 15.${PNGLIB_RELEASE}.1.5.10beta03
+# VERSION 15.${PNGLIB_RELEASE}.1.5.10beta04
VERSION 15.${PNGLIB_RELEASE}.0
SOVERSION 15
CLEAN_DIRECT_OUTPUT 1)
diff --git a/LICENSE b/LICENSE
index dc6b16a5d..4fc0b0d51 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.2.6, August 15, 2004, through 1.5.10beta03, March 5, 2012, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.10beta04, March 10, 2012, are
Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.2.5
with the following individual added to the list of Contributing Authors
@@ -108,4 +108,4 @@ certification mark of the Open Source Initiative.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-March 5, 2012
+March 10, 2012
diff --git a/README b/README
index 3bded0580..403dff55a 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.5.10beta03 - March 5, 2012 (shared library 15.0)
+README for libpng version 1.5.10beta04 - March 10, 2012 (shared library 15.0)
See the note about version numbers near the top of png.h
See INSTALL for instructions on how to install libpng.
diff --git a/configure b/configure
index cbe43118f..338224057 100755
--- a/configure
+++ b/configure
@@ -1,6 +1,6 @@
#! /bin/sh
# Guess values for system-dependent variables and create Makefiles.
-# Generated by GNU Autoconf 2.68 for libpng 1.5.10beta03.
+# Generated by GNU Autoconf 2.68 for libpng 1.5.10beta04.
#
# Report bugs to <png-mng-implement@lists.sourceforge.net>.
#
@@ -570,8 +570,8 @@ MAKEFLAGS=
# Identity of this package.
PACKAGE_NAME='libpng'
PACKAGE_TARNAME='libpng'
-PACKAGE_VERSION='1.5.10beta03'
-PACKAGE_STRING='libpng 1.5.10beta03'
+PACKAGE_VERSION='1.5.10beta04'
+PACKAGE_STRING='libpng 1.5.10beta04'
PACKAGE_BUGREPORT='png-mng-implement@lists.sourceforge.net'
PACKAGE_URL=''
@@ -1321,7 +1321,7 @@ if test "$ac_init_help" = "long"; then
# Omit some internal or obsolete options to make the list less imposing.
# This message is too long to be a string in the A/UX 3.1 sh.
cat <<_ACEOF
-\`configure' configures libpng 1.5.10beta03 to adapt to many kinds of systems.
+\`configure' configures libpng 1.5.10beta04 to adapt to many kinds of systems.
Usage: $0 [OPTION]... [VAR=VALUE]...
@@ -1391,7 +1391,7 @@ fi
if test -n "$ac_init_help"; then
case $ac_init_help in
- short | recursive ) echo "Configuration of libpng 1.5.10beta03:";;
+ short | recursive ) echo "Configuration of libpng 1.5.10beta04:";;
esac
cat <<\_ACEOF
@@ -1502,7 +1502,7 @@ fi
test -n "$ac_init_help" && exit $ac_status
if $ac_init_version; then
cat <<\_ACEOF
-libpng configure 1.5.10beta03
+libpng configure 1.5.10beta04
generated by GNU Autoconf 2.68
Copyright (C) 2010 Free Software Foundation, Inc.
@@ -1925,7 +1925,7 @@ cat >config.log <<_ACEOF
This file contains any messages produced by compilers while
running configure, to aid debugging if configure makes a mistake.
-It was created by libpng $as_me 1.5.10beta03, which was
+It was created by libpng $as_me 1.5.10beta04, which was
generated by GNU Autoconf 2.68. Invocation command line was
$ $0 $@
@@ -2740,7 +2740,7 @@ fi
# Define the identity of the package.
PACKAGE='libpng'
- VERSION='1.5.10beta03'
+ VERSION='1.5.10beta04'
cat >>confdefs.h <<_ACEOF
@@ -2804,7 +2804,7 @@ fi
-PNGLIB_VERSION=1.5.10beta03
+PNGLIB_VERSION=1.5.10beta04
PNGLIB_MAJOR=1
PNGLIB_MINOR=5
PNGLIB_RELEASE=10
@@ -13417,7 +13417,7 @@ cat >>$CONFIG_STATUS <<\_ACEOF || ac_write_fail=1
# report actual input values of CONFIG_FILES etc. instead of their
# values after options handling.
ac_log="
-This file was extended by libpng $as_me 1.5.10beta03, which was
+This file was extended by libpng $as_me 1.5.10beta04, which was
generated by GNU Autoconf 2.68. Invocation command line was
CONFIG_FILES = $CONFIG_FILES
@@ -13483,7 +13483,7 @@ _ACEOF
cat >>$CONFIG_STATUS <<_ACEOF || ac_write_fail=1
ac_cs_config="`$as_echo "$ac_configure_args" | sed 's/^ //; s/[\\""\`\$]/\\\\&/g'`"
ac_cs_version="\\
-libpng config.status 1.5.10beta03
+libpng config.status 1.5.10beta04
configured by $0, generated by GNU Autoconf 2.68,
with options \\"\$ac_cs_config\\"
diff --git a/configure.ac b/configure.ac
index b2d52c44e..c04ad868e 100644
--- a/configure.ac
+++ b/configure.ac
@@ -18,12 +18,12 @@ AC_PREREQ(2.59)
dnl Version number stuff here:
-AC_INIT([libpng], [1.5.10beta03], [png-mng-implement@lists.sourceforge.net])
+AC_INIT([libpng], [1.5.10beta04], [png-mng-implement@lists.sourceforge.net])
AM_INIT_AUTOMAKE
dnl stop configure from automagically running automake
AM_MAINTAINER_MODE
-PNGLIB_VERSION=1.5.10beta03
+PNGLIB_VERSION=1.5.10beta04
PNGLIB_MAJOR=1
PNGLIB_MINOR=5
PNGLIB_RELEASE=10
diff --git a/libpng-manual.txt b/libpng-manual.txt
index b6942f4fb..976ee77da 100644
--- a/libpng-manual.txt
+++ b/libpng-manual.txt
@@ -1,6 +1,6 @@
libpng-manual.txt - A description on how to use and modify libpng
- libpng version 1.5.10beta03 - March 5, 2012
+ libpng version 1.5.10beta04 - March 10, 2012
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2011 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@ libpng-manual.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.5.10beta03 - March 5, 2012
+ libpng versions 0.97, January 1998, through 1.5.10beta04 - March 10, 2012
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2011 Glenn Randers-Pehrson
@@ -4568,8 +4568,8 @@ above the comment that says
/* Maintainer: Put new private prototypes here ^ and in libpngpf.3 */
To avoid polluting the global namespace, the names of all exported
-functions and variables begin with "png_", and all publicly visible C
-preprocessor macros begin with "PNG_". We request that applications that
+functions and variables begin with "png_", and all publicly visible C
+preprocessor macros begin with "PNG". We request that applications that
use libpng *not* begin any of their own symbols with either of these strings.
We put a space after each comma and after each semicolon
@@ -4596,13 +4596,13 @@ Other rules can be inferred by inspecting the libpng source.
XIV. Y2K Compliance in libpng
-March 5, 2012
+March 10, 2012
Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.5.10beta03 are Y2K compliant. It is my belief that earlier
+upward through 1.5.10beta04 are Y2K compliant. It is my belief that earlier
versions were also Y2K compliant.
Libpng only has three year fields. One is a 2-byte unsigned integer that
diff --git a/libpng.3 b/libpng.3
index eae019dbd..970a824f0 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,6 +1,6 @@
-.TH LIBPNG 3 "March 5, 2012"
+.TH LIBPNG 3 "March 10, 2012"
.SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.5.10beta03
+libpng \- Portable Network Graphics (PNG) Reference Library 1.5.10beta04
.SH SYNOPSIS
\fI\fB
@@ -981,7 +981,7 @@ Following is a copy of the libpng-manual.txt file that accompanies libpng.
.SH LIBPNG.TXT
libpng-manual.txt - A description on how to use and modify libpng
- libpng version 1.5.10beta03 - March 5, 2012
+ libpng version 1.5.10beta04 - March 10, 2012
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2011 Glenn Randers-Pehrson
@@ -992,7 +992,7 @@ libpng-manual.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.5.10beta03 - March 5, 2012
+ libpng versions 0.97, January 1998, through 1.5.10beta04 - March 10, 2012
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2011 Glenn Randers-Pehrson
@@ -5550,8 +5550,8 @@ above the comment that says
/* Maintainer: Put new private prototypes here ^ and in libpngpf.3 */
To avoid polluting the global namespace, the names of all exported
-functions and variables begin with "png_", and all publicly visible C
-preprocessor macros begin with "PNG_". We request that applications that
+functions and variables begin with "png_", and all publicly visible C
+preprocessor macros begin with "PNG". We request that applications that
use libpng *not* begin any of their own symbols with either of these strings.
We put a space after each comma and after each semicolon
@@ -5578,13 +5578,13 @@ Other rules can be inferred by inspecting the libpng source.
.SH XIV. Y2K Compliance in libpng
-March 5, 2012
+March 10, 2012
Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.5.10beta03 are Y2K compliant. It is my belief that earlier
+upward through 1.5.10beta04 are Y2K compliant. It is my belief that earlier
versions were also Y2K compliant.
Libpng only has three year fields. One is a 2-byte unsigned integer that
@@ -5852,7 +5852,7 @@ possible without all of you.
Thanks to Frank J. T. Wojcik for helping with the documentation.
-Libpng version 1.5.10beta03 - March 5, 2012:
+Libpng version 1.5.10beta04 - March 10, 2012:
Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
@@ -5875,7 +5875,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.2.6, August 15, 2004, through 1.5.10beta03, March 5, 2012, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.10beta04, March 10, 2012, are
Copyright (c) 2004,2006-2007 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.2.5
with the following individual added to the list of Contributing Authors
@@ -5974,7 +5974,7 @@ certification mark of the Open Source Initiative.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-March 5, 2012
+March 10, 2012
.\" end of man page
diff --git a/libpngpf.3 b/libpngpf.3
index a9317b392..e50319431 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,6 +1,6 @@
-.TH LIBPNGPF 3 "March 5, 2012"
+.TH LIBPNGPF 3 "March 10, 2012"
.SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.5.10beta03
+libpng \- Portable Network Graphics (PNG) Reference Library 1.5.10beta04
(private functions)
.SH SYNOPSIS
\fB#include \fI"pngpriv.h"
diff --git a/png.5 b/png.5
index f0660563e..ad82d1a76 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "March 5, 2012"
+.TH PNG 5 "March 10, 2012"
.SH NAME
png \- Portable Network Graphics (PNG) format
.SH DESCRIPTION
diff --git a/png.c b/png.c
index 87573e6de..e4a6f651e 100644
--- a/png.c
+++ b/png.c
@@ -14,7 +14,7 @@
#include "pngpriv.h"
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef png_libpng_version_1_5_10beta03 Your_png_h_is_not_version_1_5_10beta03;
+typedef png_libpng_version_1_5_10beta04 Your_png_h_is_not_version_1_5_10beta04;
/* Tells libpng that we have already handled the first "num_bytes" bytes
* of the PNG file signature. If the PNG data is embedded into another
@@ -655,13 +655,13 @@ png_get_copyright(png_const_structp png_ptr)
#else
# ifdef __STDC__
return PNG_STRING_NEWLINE \
- "libpng version 1.5.10beta03 - March 5, 2012" PNG_STRING_NEWLINE \
+ "libpng version 1.5.10beta04 - March 10, 2012" PNG_STRING_NEWLINE \
"Copyright (c) 1998-2011 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
"Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
"Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
PNG_STRING_NEWLINE;
# else
- return "libpng version 1.5.10beta03 - March 5, 2012\
+ return "libpng version 1.5.10beta04 - March 10, 2012\
Copyright (c) 1998-2011 Glenn Randers-Pehrson\
Copyright (c) 1996-1997 Andreas Dilger\
Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.";
diff --git a/pngconf.h b/pngconf.h
index 044c1aebb..8ba273b6e 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
/* pngconf.h - machine configurable file for libpng
*
- * libpng version 1.5.10beta03 - March 5, 2012
+ * libpng version 1.5.10beta04 - March 10, 2012
*
* Copyright (c) 1998-2012 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -51,8 +51,8 @@
/* This controls optimization of the reading of 16 and 32 bit values
* from PNG files. It can be set on a per-app-file basis - it
- * just changes whether a macro is used to the function is called.
- * The library builder sets the default, if read functions are not
+ * just changes whether a macro is used when the function is called.
+ * The library builder sets the default; if read functions are not
* built into the library the macro implementation is forced on.
*/
#ifndef PNG_READ_INT_FUNCTIONS_SUPPORTED
diff --git a/pngtest.c b/pngtest.c
index 805412bd4..2aeeeb84b 100644
--- a/pngtest.c
+++ b/pngtest.c
@@ -1817,4 +1817,4 @@ main(int argc, char *argv[])
}
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef png_libpng_version_1_5_10beta03 Your_png_h_is_not_version_1_5_10beta03;
+typedef png_libpng_version_1_5_10beta04 Your_png_h_is_not_version_1_5_10beta04;
diff --git a/pngwutil.c b/pngwutil.c
index da18e9502..366d98a9e 100644
--- a/pngwutil.c
+++ b/pngwutil.c
@@ -569,14 +569,15 @@ png_text_compress(png_structp png_ptr,
/* Ship the compressed text out via chunk writes */
static void /* PRIVATE */
-png_write_compressed_data_out(png_structp png_ptr, compression_state *comp)
+png_write_compressed_data_out(png_structp png_ptr, compression_state *comp,
+ png_size_t data_len)
{
int i;
/* Handle the no-compression case */
if (comp->input)
{
- png_write_chunk_data(png_ptr, comp->input, comp->input_len);
+ png_write_chunk_data(png_ptr, comp->input, data_len);
return;
}
@@ -585,7 +586,7 @@ png_write_compressed_data_out(png_structp png_ptr, compression_state *comp)
/* The zbuf_size test is because the code below doesn't work if zbuf_size is
* '1'; simply skip it to avoid memory overwrite.
*/
- if (comp->input_len >= 2 && comp->input_len < 16384 && png_ptr->zbuf_size > 1)
+ if (data_len >= 2 && comp->input_len < 16384 && png_ptr->zbuf_size > 1)
{
unsigned int z_cmf; /* zlib compression method and flags */
@@ -1164,8 +1165,7 @@ png_write_iCCP(png_structp png_ptr, png_const_charp name, int compression_type,
if (profile_len)
{
- comp.input_len = profile_len;
- png_write_compressed_data_out(png_ptr, &comp);
+ png_write_compressed_data_out(png_ptr, &comp, profile_len);
}
png_write_chunk_end(png_ptr);
@@ -1735,8 +1735,7 @@ png_write_zTXt(png_structp png_ptr, png_const_charp key, png_const_charp text,
png_write_chunk_data(png_ptr, &buf, (png_size_t)1);
/* Write the compressed data */
- comp.input_len = text_len;
- png_write_compressed_data_out(png_ptr, &comp);
+ png_write_compressed_data_out(png_ptr, &comp, text_len);
/* Close the chunk */
png_write_chunk_end(png_ptr);
@@ -1827,7 +1826,7 @@ png_write_iTXt(png_structp png_ptr, int compression, png_const_charp key,
png_write_chunk_data(png_ptr, (lang_key ? (png_const_bytep)lang_key : cbuf),
(png_size_t)(lang_key_len + 1));
- png_write_compressed_data_out(png_ptr, &comp);
+ png_write_compressed_data_out(png_ptr, &comp, text_len);
png_write_chunk_end(png_ptr);
diff --git a/projects/vstudio/readme.txt b/projects/vstudio/readme.txt
index b78286d24..934b7961c 100644
--- a/projects/vstudio/readme.txt
+++ b/projects/vstudio/readme.txt
@@ -1,7 +1,7 @@
VisualStudio instructions
-libpng version 1.5.10beta03 - March 5, 2012
+libpng version 1.5.10beta04 - March 10, 2012
Copyright (c) 1998-2010 Glenn Randers-Pehrson
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index 3a6ff6d4d..5e0379dff 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
<!--
* zlib.props - location of zlib source
*
- * libpng version 1.5.10beta03 - March 5, 2012
+ * libpng version 1.5.10beta04 - March 10, 2012
*
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
*
diff --git a/scripts/README.txt b/scripts/README.txt
index b1f795079..c053fa04f 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,9 +1,9 @@
-Makefiles for libpng version 1.5.10beta03 - March 5, 2012
+Makefiles for libpng version 1.5.10beta04 - March 10, 2012
pnglibconf.h.prebuilt => Stores configuration settings
makefile.linux => Linux/ELF makefile
- (gcc, creates libpng15.so.15.1.5.10beta03)
+ (gcc, creates libpng15.so.15.1.5.10beta04)
makefile.gcc => Generic makefile (gcc, creates static libpng.a)
makefile.knr => Archaic UNIX Makefile that converts files with
ansi2knr (Requires ansi2knr.c from
@@ -20,7 +20,7 @@ pnglibconf.h.prebuilt => Stores configuration settings
makefile.dec => DEC Alpha UNIX makefile
makefile.dj2 => DJGPP 2 makefile
makefile.elf => Linux/ELF makefile symbol versioning,
- (gcc, creates libpng15.so.15.1.5.10beta03)
+ (gcc, creates libpng15.so.15.1.5.10beta04)
makefile.freebsd => FreeBSD makefile
makefile.gcc => Generic gcc makefile
makefile.hpgcc => HPUX makefile using gcc
@@ -35,12 +35,12 @@ pnglibconf.h.prebuilt => Stores configuration settings
makefile.os2 => OS/2 Makefile (gcc and emx, requires libpng.def)
makefile.sco => For SCO OSr5 ELF and Unixware 7 with Native cc
makefile.sggcc => Silicon Graphics (gcc,
- creates libpng15.so.15.1.5.10beta03)
+ creates libpng15.so.15.1.5.10beta04)
makefile.sgi => Silicon Graphics IRIX makefile (cc, creates static lib)
makefile.solaris => Solaris 2.X makefile (gcc,
- creates libpng15.so.15.1.5.10beta03)
+ creates libpng15.so.15.1.5.10beta04)
makefile.so9 => Solaris 9 makefile (gcc,
- creates libpng15.so.15.1.5.10beta03)
+ creates libpng15.so.15.1.5.10beta04)
makefile.std => Generic UNIX makefile (cc, creates static libpng.a)
makefile.sunos => Sun makefile
makefile.32sunu => Sun Ultra 32-bit makefile
diff --git a/scripts/libpng-config-head.in b/scripts/libpng-config-head.in
index 75554475e..9f0de053c 100755
--- a/scripts/libpng-config-head.in
+++ b/scripts/libpng-config-head.in
@@ -11,7 +11,7 @@
# Modeled after libxml-config.
-version=1.5.10beta03
+version=1.5.10beta04
prefix=""
libdir=""
libs=""
diff --git a/scripts/libpng.pc.in b/scripts/libpng.pc.in
index 583ab0da3..e1d894384 100644
--- a/scripts/libpng.pc.in
+++ b/scripts/libpng.pc.in
@@ -5,6 +5,6 @@ includedir=@includedir@/libpng15
Name: libpng
Description: Loads and saves PNG files
-Version: 1.5.10beta03
+Version: 1.5.10beta04
Libs: -L${libdir} -lpng15
Cflags: -I${includedir}
diff --git a/scripts/makefile.ne12bsd b/scripts/makefile.ne12bsd
index cc3fe99c4..a4ef44818 100644
--- a/scripts/makefile.ne12bsd
+++ b/scripts/makefile.ne12bsd
@@ -17,7 +17,7 @@ INCSDIR=${LOCALBASE}/include/libpng15
LIB= png15
SHLIB_MAJOR= 0
-SHLIB_MINOR= 1.5.10beta03
+SHLIB_MINOR= 1.5.10beta04
SRCS= png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.netbsd b/scripts/makefile.netbsd
index bdc086378..dc0f668d3 100644
--- a/scripts/makefile.netbsd
+++ b/scripts/makefile.netbsd
@@ -17,7 +17,7 @@ INCSDIR=${LOCALBASE}/include
LIB= png
SHLIB_MAJOR= 15
-SHLIB_MINOR= 1.5.10beta03
+SHLIB_MINOR= 1.5.10beta04
SRCS= png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.openbsd b/scripts/makefile.openbsd
index 9b824af0b..2804aeb16 100644
--- a/scripts/makefile.openbsd
+++ b/scripts/makefile.openbsd
@@ -11,7 +11,7 @@ LIBDIR= ${PREFIX}/lib
MANDIR= ${PREFIX}/man/cat
SHLIB_MAJOR= 15
-SHLIB_MINOR= 1.5.10beta03
+SHLIB_MINOR= 1.5.10beta04
LIB= png
SRCS= png.c pngerror.c pngget.c pngmem.c pngpread.c \
diff --git a/scripts/pnglibconf.h.prebuilt b/scripts/pnglibconf.h.prebuilt
index 6528db099..506240af1 100644
--- a/scripts/pnglibconf.h.prebuilt
+++ b/scripts/pnglibconf.h.prebuilt
@@ -3,7 +3,7 @@
/* pnglibconf.h - library build configuration */
-/* Libpng 1.5.10beta03 - March 5, 2012 */
+/* Libpng 1.5.10beta04 - March 10, 2012 */
/* Copyright (c) 1998-2012 Glenn Randers-Pehrson */
diff --git a/scripts/symbols.def b/scripts/symbols.def
index 826c2ee3f..ca1b20e65 100644
--- a/scripts/symbols.def
+++ b/scripts/symbols.def
@@ -5,7 +5,7 @@
LIBRARY
EXPORTS
-;Version 1.5.10beta03
+;Version 1.5.10beta04
png_access_version_number @1
png_set_sig_bytes @2
png_sig_cmp @3
diff --git a/png.h b/png.h
index 42ec271d2..2ae668631 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.5.10beta03 - March 5, 2012
* Copyright (c) 1998-2012 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.5.10beta03 - March 5, 2012: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -204,7 +204,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.5.10beta03, March 5, 2012, are
* Copyright (c) 2004, 2006-2012 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -316,13 +316,13 @@
* Y2K compliance in libpng:
* =========================
*
- * March 5, 2012
+ * March 10, 2012
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.5.10beta03 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*
* Libpng only has two year fields. One is a 2-byte unsigned integer
@@ -380,9 +380,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.5.10beta03"
+#define PNG_LIBPNG_VER_STRING "1.5.10beta04"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.5.10beta03 - March 5, 2012\n"
+ " libpng version 1.5.10beta04 - March 10, 2012\n"
#define PNG_LIBPNG_VER_SONUM 15
#define PNG_LIBPNG_VER_DLLNUM 15
@@ -396,7 +396,7 @@
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
*/
-#define PNG_LIBPNG_VER_BUILD 03
+#define PNG_LIBPNG_VER_BUILD 04
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -543,7 +543,7 @@ extern "C" {
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef char* png_libpng_version_1_5_10beta03;
+typedef char* png_libpng_version_1_5_10beta04;
/* Three color definitions. The order of the red, green, and blue, (and the
* exact size) is not important, although the size of the fields need to
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.5.10beta03 - March 5, 2012
+ * libpng version 1.5.10beta04 - March 10, 2012
* Copyright (c) 1998-2012 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.5.10beta03 - March 5, 2012: Glenn
+ * libpng versions 0.97, January 1998, through 1.5.10beta04 - March 10, 2012: Glenn
* See also "Contributing Authors", below.
*
@@ -204,7 +204,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.5.10beta03, March 5, 2012, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.5.10beta04, March 10, 2012, are
* Copyright (c) 2004, 2006-2012 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
@@ -316,13 +316,13 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.5.10beta03 are Y2K compliant. It is my belief that
+ * upward through 1.5.10beta04 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*